@@ -4,8 +4,8 @@
 
 ;; Author: Håvard Damm-Johnsen <havard-dj@proton.me>
 ;; URL: https://github.com/havarddj/typst-preview.el
-;; Package-Version: 20251110.824
-;; Package-Revision: c685857f2d61
+;; Package-Version: 20260215.2252
+;; Package-Revision: 7e89cf105e4f
 ;; Package-Requires: ((emacs "28.1") (websocket "1.15") (compat "30.1"))
 ;; Keywords: convenience, languages, tools
 
@@ -70,7 +70,7 @@
   :group 'Languages
   :link '(url-link "https://github.com/havarddj/typst-preview.el"))
 
-;;;; Variables
+;;;; Functions
 
 ;; PUBLIC
 
@@ -117,23 +117,36 @@ This is intended for multi-file projects where a file is included
   :group 'typst-preview)
 
 (defcustom typst-preview-center-src t
-  "If non-NIL, center typst preview source buffer when jumping to source." :type 'boolean :group 'typst-preview)
+  "If non-NIL, center typst preview source buffer when jumping to source."
+  :type 'boolean
+  :group 'typst-preview)
 
 (defcustom typst-preview-partial-rendering nil
   "If non-NIL, only render part of the document which is visible."
-  :type 'boolean :group 'typst-preview)
+  :type 'boolean
+  :group 'typst-preview)
 
 (defvar typst-preview-host "127.0.0.1:0"
   "Default address for typst websocket.")
 
 (defcustom typst-preview-cmd-options '()
   "Additional command line options for preview program.
-Should be a list of strings."
-  :type '(repeat string) :group 'typst-preview)
+
+For tinymist, run `tinymist preview -h' to see available options.
+Should be a list of strings, each of which contains no spaces."
+  :type '(repeat string)
+  :group 'typst-preview)
 
 (defcustom typst-preview-default-dir "."
   "Default root directory for preview. Can be a relative path."
-  :type 'string :group 'typst-preview)
+  :type 'string
+  :group 'typst-preview)
+
+(defcustom typst-preview-preview-mode "document"
+  "Configure the preview mode (document or slides)."
+  :type 'string
+  :group 'typst-preview
+  :options '("document" "slide"))
 
 ;; PRIVATE
 
@@ -236,6 +249,7 @@ open a default browser window."
 	       "--data-plane-host" "127.0.0.1:0"
 	       "--root" ,(file-truename typst-preview-default-dir)
 	       "--invert-colors" ,typst-preview-invert-colors
+	       "--preview-mode" ,typst-preview-preview-mode
 	       ,@typst-preview-cmd-options ,typst-preview--master-file)))
 	(setf (typst-preview--master-process typst-preview--local-master)
 	      (apply #'start-process "typst-preview-proc" (get-buffer-create "*ws-typst-server*") preview-args)))
